@@ -252,20 +252,16 @@ plip_dialog_check_fields (GstConnectionDialog *dialog)
 }
 
 static void
-modem_dialog_prepare (GstConnectionDialog *dialog)
+isdn_dialog_prepare (GstConnectionDialog *dialog)
 {
-  gchar    *login, *password, *serial_port, *phone_number, *dial_prefix;
-  gint      volume, dial_type;
+  gchar    *login, *password, *phone_number, *dial_prefix;
   gboolean  default_gw, persist;
 
   g_object_get (G_OBJECT (dialog->iface),
                 "iface-login", &login,
                 "iface-password", &password,
-                "iface-serial-port", &serial_port,
                 "iface-phone-number", &phone_number,
                 "iface-dial-prefix", &dial_prefix,
-                "iface-volume", &volume,
-                "iface-dial-type", &dial_type,
                 "iface-default-gw", &default_gw,
                 "iface-persist", &persist,
                 NULL);
@@ -276,41 +272,71 @@ modem_dialog_prepare (GstConnectionDialog *dialog)
   gtk_entry_set_text (GTK_ENTRY (dialog->password),
                       (password) ? password : "");
 
-  gtk_entry_set_text (GTK_ENTRY (GTK_BIN (dialog->serial_port)->child),
-                      (serial_port) ? serial_port : "");
-
   gtk_entry_set_text (GTK_ENTRY (dialog->phone_number),
                       (phone_number) ? phone_number : "");
 
   gtk_entry_set_text (GTK_ENTRY (dialog->dial_prefix),
                       (dial_prefix) ? dial_prefix : "");
 
-  gtk_combo_box_set_active (GTK_COMBO_BOX (dialog->volume), volume);
-  gtk_combo_box_set_active (GTK_COMBO_BOX (dialog->dial_type), dial_type);
-
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->default_gw), default_gw);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->persist), persist);
 
   g_free (login);
   g_free (password);
-  g_free (serial_port);
   g_free (phone_number);
   g_free (dial_prefix);
 }
 
+static void
+isdn_dialog_save (GstConnectionDialog *dialog)
+{
+  g_object_set (G_OBJECT (dialog->iface),
+                "iface-login",        get_entry_text (dialog->login),
+                "iface-password",     get_entry_text (dialog->password),
+                "iface-phone-number", get_entry_text (dialog->phone_number),
+                "iface-dial-prefix",  get_entry_text (dialog->dial_prefix),
+                "iface-default-gw",   gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->default_gw)),
+                "iface-persist",      gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->persist)),
+                NULL);
+}
+
+static gboolean
+isdn_dialog_check_fields (GstConnectionDialog *dialog)
+{
+  return ((!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->connection_ppp_configured))) ||
+	  ((get_entry_text (dialog->login)) &&
+	   (get_entry_text (dialog->password)) &&
+	   (get_entry_text (dialog->phone_number))));
+}
+
+static void
+modem_dialog_prepare (GstConnectionDialog *dialog)
+{
+  gchar *serial_port;
+  gint   volume, dial_type;
+
+  g_object_get (G_OBJECT (dialog->iface),
+                "iface-serial-port", &serial_port,
+                "iface-volume", &volume,
+                "iface-dial-type", &dial_type,
+                NULL);
+
+  gtk_entry_set_text (GTK_ENTRY (GTK_BIN (dialog->serial_port)->child),
+                      (serial_port) ? serial_port : "");
+
+  gtk_combo_box_set_active (GTK_COMBO_BOX (dialog->volume), volume);
+  gtk_combo_box_set_active (GTK_COMBO_BOX (dialog->dial_type), dial_type);
+
+  g_free (serial_port);
+}
+
 static void
 modem_dialog_save (GstConnectionDialog *dialog)
 {
   g_object_set (G_OBJECT (dialog->iface),
-                "iface-login",        get_entry_text (dialog->login),
-                "iface-password",     get_entry_text (dialog->password),
                 "iface-serial-port",  get_entry_text (GTK_BIN (dialog->serial_port)->child),
-		"iface-phone-number", get_entry_text (dialog->phone_number),
-                "iface-dial-prefix",  get_entry_text (dialog->dial_prefix),
                 "iface-volume",       gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->volume)),
                 "iface-dial-type",    gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->dial_type)),
-                "iface-default-gw",   gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->default_gw)),
-                "iface-persist",      gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->persist)),
 		NULL);
 }
 
@@ -318,10 +344,7 @@ static gboolean
 modem_dialog_check_fields (GstConnectionDialog *dialog)
 {
   return ((!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->connection_ppp_configured))) ||
-	  ((get_entry_text (dialog->login)) &&
-	   (get_entry_text (dialog->password)) &&
-	   (get_entry_text (GTK_BIN (dialog->serial_port)->child)) &&
-	   (get_entry_text (dialog->phone_number))));
+	  (get_entry_text (GTK_BIN (dialog->serial_port)->child)));
 }
 
 GstConnectionDialog*
@@ -340,7 +363,7 @@ connection_dialog_init (void)
   gcd->notebook         = gst_dialog_get_widget (tool->main_dialog, "connection_notebook");
   gcd->general_page     = gst_dialog_get_widget (tool->main_dialog, "connection_general_page");
   gcd->ppp_general_page = gst_dialog_get_widget (tool->main_dialog, "connection_ppp_general_page");
-  gcd->account_page     = gst_dialog_get_widget (tool->main_dialog, "connection_account_page");
+  gcd->modem_page       = gst_dialog_get_widget (tool->main_dialog, "connection_modem_page");
   gcd->options_page     = gst_dialog_get_widget (tool->main_dialog, "connection_options_page");
 
   gcd->connection_configured = gst_dialog_get_widget (tool->main_dialog, "connection_device_active");
@@ -388,13 +411,15 @@ connection_dialog_init (void)
 void
 connection_dialog_prepare (GstConnectionDialog *dialog, GstIface *iface)
 {
+  gboolean active;
+
   dialog->iface = g_object_ref (iface);
+  active = gst_iface_is_configured (dialog->iface);
   
-  if (GST_IS_IFACE_MODEM (iface))
+  if (GST_IS_IFACE_ISDN (iface) || GST_IS_IFACE_MODEM (iface))
     {
       gtk_widget_hide (dialog->general_page);
       gtk_widget_show (dialog->ppp_general_page);
-      gtk_widget_show (dialog->account_page);
       gtk_widget_show (dialog->options_page);
 
       gtk_notebook_set_show_tabs (GTK_NOTEBOOK (dialog->notebook), TRUE);
@@ -403,18 +428,27 @@ connection_dialog_prepare (GstConnectionDialog *dialog, GstIface *iface)
       gtk_container_set_border_width (GTK_CONTAINER (dialog->notebook), 6);
 
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->connection_ppp_configured),
-				    gst_iface_is_configured (iface));
+				    active);
 
       gtk_label_set_text (GTK_LABEL (dialog->connection_ppp_device),
 			  gst_iface_get_dev (iface));
 
-      modem_dialog_prepare (dialog);
+      isdn_dialog_prepare (dialog);
+
+      /* extra stuff needed for modem devices */
+      if (GST_IS_IFACE_MODEM (iface))
+        {
+	  gtk_widget_show (dialog->modem_page);
+	  modem_dialog_prepare (dialog);
+	}
+      else
+	gtk_widget_hide (dialog->modem_page);
     }
   else
     {
       gtk_widget_show (dialog->general_page);
       gtk_widget_hide (dialog->ppp_general_page);
-      gtk_widget_hide (dialog->account_page);
+      gtk_widget_hide (dialog->modem_page);
       gtk_widget_hide (dialog->options_page);
 
       gtk_notebook_set_show_tabs (GTK_NOTEBOOK (dialog->notebook), FALSE);
@@ -457,6 +491,7 @@ connection_dialog_prepare (GstConnectionDialog *dialog, GstIface *iface)
 	}
     }
 
+  connection_dialog_set_sensitive (dialog, active);
   dialog->changed = FALSE;
 }
 
@@ -465,10 +500,14 @@ connection_save (GstConnectionDialog *dialog)
 {
   gboolean active;
 
-  if (GST_IS_IFACE_MODEM (dialog->iface))
+  if (GST_IS_IFACE_MODEM (dialog->iface)
+      || GST_IS_IFACE_ISDN (dialog->iface))
     {
       active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->connection_ppp_configured));
-      modem_dialog_save (dialog);
+      isdn_dialog_save (dialog);
+
+      if (GST_IS_IFACE_MODEM (dialog->iface))
+	modem_dialog_save (dialog);
     }
   else
     {
@@ -502,8 +541,11 @@ connection_check_fields (GstConnectionDialog *dialog)
     active = ethernet_dialog_check_fields (dialog);
   else if (GST_IS_IFACE_PLIP (dialog->iface))
     active = plip_dialog_check_fields (dialog);
+  else if (GST_IS_IFACE_MODEM (dialog->iface))
+    active = (isdn_dialog_check_fields (dialog) &&
+	      modem_dialog_check_fields (dialog));
   else
-    active = modem_dialog_check_fields (dialog);
+    active = isdn_dialog_check_fields (dialog);
 
   gtk_widget_set_sensitive (dialog->ok_button, active);
 }
@@ -544,3 +586,14 @@ connection_check_netmask (GtkWidget *address_widget, GtkWidget *netmask_widget)
         gtk_entry_set_text (GTK_ENTRY (netmask_widget), "255.255.255.0");
     }
 }
+
+void
+connection_dialog_set_sensitive (GstConnectionDialog *dialog, gboolean active)
+{
+  gtk_widget_set_sensitive (dialog->wireless_frame, active);
+  gtk_widget_set_sensitive (dialog->ethernet_frame, active);
+  gtk_widget_set_sensitive (dialog->plip_frame,     active);
+  gtk_widget_set_sensitive (dialog->modem_frame,    active);
+  gtk_widget_set_sensitive (dialog->modem_page,     active);
+  gtk_widget_set_sensitive (dialog->options_page,   active);
+}
