@@ -25,7 +25,12 @@
 #define __PRIVILEGES_TABLE_H
 
 void     create_user_privileges_table      (void);
-void     populate_user_privileges_table    (gchar*);
+void     create_profile_privileges_table   (void);
+
+void     populate_privileges_table         (GtkWidget*, gchar*);
+void     populate_privileges_table_from_profile (xmlNodePtr);
+
 GList*   user_privileges_get_list          (GList*);
 
+
 #endif /* __PRIVILEGES_TABLE_H */
